<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl

$newuser_text = array (

'registernewuser'	=>	'Rejestracja nowego użytkownika',
'requiredfields'=>	'Wymagane pola są oznaczone znakiem',
'username'	=>	'Nazwa',
'password'	=>	'Hasło',
'confirmpass'	=>	'Potwierdź hasło',
'realname'	=>	'Imię i nazwisko',
'emailaddress'	=>	'Adres e-mail',
'jabberid'	=>	'Jabber ID',
'notifications'	=>	'Powiadomienia',
'none'		=>	'Brak',
'email'		=>	'E-mail',
'jabber'	=>	'Jabber',
'group'		=>	'Grupa',
'registeraccount'=>	'Utwórz konto',

// New in 0.9.7
'globalgroup'		=>	'Grupa globalna',

);
// vim:fenc=utf-8:enc=utf-8
?>
